from django.apps import AppConfig


class LoadingAppConfig(AppConfig):
    name = 'i18n.loading_app'
